#!/bin/sh

# Crash-diagnostics tool will use user "vmware-system-user" to fetch logs and node stats
# Due to the permission issue, we need to copy all those outputs to another folder to let Crash-diagnostics grab them.

set -x
LOG_DIR=/home/vmware-system-user

# Process/OS
ulimit -a &> ulimit.out
sysctl -a &> sysctl.out
cat /proc/loadavg &> loadavg.out
cat /proc/sys/kernel/threads-max &> threads-max.out
ps -elf &> pself.out
ps -elfT &> psthreads.out
cat /proc/sys/fs/file-nr &> file-nr.out
cat /proc/sys/fs/file-max &> file-max.out
lsof -n &> lsof-n.out
uname -a &> uname.out
vmstat 1 5 &> vmstat.out
sar -A &> sar-A.out
pidstat -p ALL -T ALL -I -l -r  -t  -u &> pidstat.out
cat /proc/vmstat &> proc-vmstat.out

# Memory
ps -eo pid,ppid,cmd,vsz,fuser,%mem,%cpu --sort=-%mem | head -n 20 &> psmem.out
cat /proc/meminfo &> mem-info.out
vmstat -m &> vmstat-m.out
cat /proc/slabinfo &> slabinfo.out
slabtop -s c -o &> slabtop.out
free -m &> free-m.out

# CPU
ps -eo pid,ppid,cmd,vsz,fuser,%mem,%cpu --sort=-%cpu | head -n 20 &> pscpu.out
cat /proc/cpuinfo &> cpuinfo.out
cat /proc/softirqs &> softirqs.out
cat /proc/interrupts &> interrupts.out
lscpu &> lscpu.out
uptime &> uptime.out
mpstat 1 5 -P ALL &> mpstat-all.out

# Network
netstat -lantupWe &> netstat-lantupWe.out
netstat -i &> netstat-i.out
netstat -s &> netstat-s.out
ss -noemitaup &> ss-noemitaup.out
cat /proc/net/dev &> proc-net-dev.out
cat /proc/net/sockstat &> sockstat.out
cat /proc/net/sockstat6 &> sockstat6.out
ip addr &> ip-addr.out
route -n &> route-n.out
ip rule list &> ip-rule-list.out
ip route show table all &> ip-show-table.out
iptables -L -v -n --line-numbers &> iptables-all.out
conntrack -L &> conntrack-L.out
conntrack -S &> conntrack-S.out

# Disk/IO
df -ih --total &> df-ih.out
df -ah --total &> df-ah.out
arp -an &> arp-an.out
iostat 1 5 &> iostat.out

# Bundle Artifacts
sudo tar czvf ${LOG_DIR}/node-stats.gz *.out

chown -R vmware-system-user ${LOG_DIR}/node-stats.gz